% EXPLOREVFIELD provides a GUI for exploring vector fields. It offers Zoom-in, Zoom-out and Animation capabilities.
% Usage:
% [RECT, LICMOVIE] = EXPLOREVFIELD (VX, VY) brings up the GUI for the
% vector field by VX and VY.
% VX and VY should contain X and Y components of the vector field. They
% should be M x N floating point arrays with equal sizes.
% 
% RECT returns the last region selected in a 4-element vector with the form [XMIN YMIN WIDTH HEIGHT].
% LICMOVIE returns the last Matlab movie generated by 'Make Animation'
% command.

function [rect, LICmovie] = explorevfield(vx,vy, ColorMap);
if nargin < 3 
    ColorMap = jet;
end;
[width,height] = size(vx);
LICmovie = [];
rect = [ 1 1 height width];
rectNum = 1;
rectStack(:,:,rectNum) = rect;
vxCropped = vx;
vyCropped = vy;
command = '1';
needRepaint = true;
while command ~= 'e'
    command = '1';
    if needRepaint 
        [cwidth,cheight] = size(vxCropped);
        [preview ,zoomFactor]= previewvfield(vxCropped,vyCropped, ColorMap);
        [pwidth,pheight,temp] = size(preview);
        needRepaint = false;
    end;
    actions(1) = 'z';
    actions(2) = 'o';
    actions(3) = 'a';
    actions(4) = 'e';
    k = menu('Please choose an action:','Zoom In','Zoom Out','Make Animation','Exit');
    command = actions(k);
    
    if command == 'z'
        'Please mark a region to zoom:'
		close;
        figure;
        [preview,rect2] = imcrop([1 pheight], [1 pwidth],preview);
        rect2(2) = rect2(2) * cwidth/ pwidth;
        rect2(4) = rect2(4) * cwidth/ pwidth;
        rect2(1) = rect2(1) * cheight/ pheight;
        rect2(3) = rect2(3) * cheight/ pheight;
        rect = [rect(1)+rect2(1) rect(2)+rect2(2) rect2(3) rect2(4)];
        
        disp('Zooming region:');
        disp(rect);
        
        rectNum = rectNum + 1;
        rectStack(:,:,rectNum) = rect;
        vxCropped = imcrop([1 height], [1 width],vx,rect);
        vyCropped = imcrop([1 height], [1 width],vy,rect);
        needRepaint = true;
    end;
    
    if command == 'o'
        if rectNum == 1 
            'Maximum Zoom Out reached.'
        end;
    if rectNum > 1 
        rect = rectStack(:,:,rectNum - 1);
        rectNum = rectNum - 1;
        vxCropped = imcrop([1 height], [1 width],vx,rect);
        vyCropped = imcrop([1 height], [1 width],vy,rect);
        needRepaint = true;
    end;
    end;
    
    if command == 'a'
        figure;
        LICmovie = animvfield(vx,vy,zoomFactor, 10, ColorMap, rect);
        q = 1;
        while (q ==1)
            movie(LICmovie,10);
            q = menu('Would you like to see the movie again?','Yes','No');
         end;
         'Movie saved in the returned variable'
        close;  
    end;
    
end;